"""Caffeinate Me - A whimsical caffeine companion for coffee-loving developers."""

__version__ = "0.2.0"
__author__ = "The Coffee Collective"

from .core import caffeinate_me

__all__ = ["caffeinate_me", "__version__"]
